flutter_isolate_ohos library
Classes
Functions
-
flutterCompute<
T, U> (FutureOr< T> callback(U message), U message) → Future<T> -
A function that spawns a flutter isolate and runs the provided
callbackon that isolate, passes it the providedmessage, and (eventually) returns the value returned bycallback.